@@ -367,7 +367,7 @@ static int handle_udp_packet(dtls_listener_relay_server_type *server,
 			}
 		}
 
-		if(ioa_socket_check_bandwidth(s,sm->m.sm.nd.nbh,1)) {
+		if(s && ioa_socket_check_bandwidth(s,sm->m.sm.nd.nbh,1)) {
 			s->e = ioa_eng;
 			if (s && s->read_cb && sm->m.sm.nd.nbh) {
 				s->read_cb(s, IOA_EV_READ, &(sm->m.sm.nd), s->read_ctx, 1);
